@@ -11,7 +11,7 @@ _cook_persistence = None
 def initialize():
     global _cook_persistence
     _cook_persistence = PluginManager.get_plugin(
-        "cook_persistence_interface")
+        "cook_persistence_plug_point")
 
 
 def add_cook(cook):
