@@ -1,6 +1,6 @@
 from collections import defaultdict
 
-from qb_core.rats_pkg.cook.cook_persistence_interface import CookPersistenceInterface
+from qb_core.rats_pkg.cook.cook_persistence_plug_point import CookPersistenceInterface
 
 cook_dict = {}
 
